@@ -106,6 +106,10 @@ ResourcesRequest::ResourcesRequest(QObject *parent) :
     \endcode
 */
 void ResourcesRequest::list(const QString &resourcePath, const QVariantMap &filters, const QStringList &fields) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
 #if QT_VERSION >= 0x050000
@@ -145,6 +149,10 @@ void ResourcesRequest::list(const QString &resourcePath, const QVariantMap &filt
     \endcode
 */
 void ResourcesRequest::get(const QString &resourcePath, const QVariantMap &filters, const QStringList &fields) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
 #if QT_VERSION >= 0x050000
@@ -184,6 +192,10 @@ void ResourcesRequest::get(const QString &resourcePath, const QVariantMap &filte
     \endcode
 */
 void ResourcesRequest::insert(const QString &resourcePath) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     setUrl(u);
@@ -205,6 +217,10 @@ void ResourcesRequest::insert(const QString &resourcePath) {
     \endcode
 */
 void ResourcesRequest::insert(const QVariantMap &resource, const QString &resourcePath) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     QString body;
@@ -228,6 +244,10 @@ void ResourcesRequest::insert(const QVariantMap &resource, const QString &resour
     \endcode
 */
 void ResourcesRequest::update(const QString &resourcePath, const QVariantMap &resource) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     QString body;
@@ -248,6 +268,10 @@ void ResourcesRequest::update(const QString &resourcePath, const QVariantMap &re
     \endcode
 */
 void ResourcesRequest::del(const QString &resourcePath) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     setUrl(u);
