@@ -47,13 +47,13 @@ public:
                 }
                 
                 q->endInsertRows();
-                emit q->countChanged();
+                emit q->countChanged(q->rowCount());
             }
         }
         
         StreamsModel::disconnect(request, SIGNAL(finished()), q, SLOT(_q_onListRequestFinished()));
     
-        emit q->statusChanged();
+        emit q->statusChanged(request->status());
     }
     
     StreamsRequest *request;
@@ -100,6 +100,10 @@ public:
             <td>HeightRole</td>
             <td>height</td>
         </tr>
+        <tr>
+            <td>UrlRole</td>
+            <td>url</td>
+        </tr>
     </table>
         
     Example usage:
@@ -162,6 +166,7 @@ StreamsModel::StreamsModel(QObject *parent) :
     d->roles[ExtensionRole] = "ext";
     d->roles[WidthRole] = "width";
     d->roles[HeightRole] = "height";
+    d->roles[UrlRole] = "url";
 #if QT_VERSION < 0x050000
     setRoleNames(d->roles);
 #endif
@@ -185,6 +190,18 @@ StreamsRequest::Status StreamsModel::status() const {
     return d->request->status();
 }
 
+/*!
+    \property QVariant StreamsModel::result
+    \brief The current result of the model.
+    
+    \sa StreamsRequest::result
+*/
+QVariant StreamsModel::result() const {
+    Q_D(const StreamsModel);
+    
+    return d->request->result();
+}
+
 /*!
     \property enum StreamsModel::error
     \brief The error type of the model.
@@ -236,7 +253,7 @@ void StreamsModel::list(const QString &id) {
         clear();
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onListRequestFinished()));
         d->request->list(id);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
@@ -262,7 +279,7 @@ void StreamsModel::reload() {
         clear();
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onListRequestFinished()));
         d->request->list(d->id);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
